/*
 * File   : index.js
 * Created: 2018/11/9 1:17:27 pm
 * Author : quym
 * License: MIT License
 *
 * Copyright (c) 2018 quym
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * -----
 * Last Modified: 2018/11/15 10:36:22 am
 * Modified By  : quym at <quym@gmail.com>
 * -----
 * Description: 按月查询功能、导出图表功能、圆环图点击弹出供应商列表清单功能、地图下钻与返回功能、地图与其他图表联动功能
 * 定时动态刷新功能暂无，若需要可增加
 * -----
 * HISTORY:
 * 2018/11/9	quym	完成基本功能
 * 2018/11/14	quym	日期框缩小，地图放大，圆环图点击可弹出供应商清单
 * -----
 * mark: 页面图表均使用百度echarts绘图工具绘制  参考链接：http://echarts.baidu.com
 */

//layui初始化
layui.use(['element', 'table', 'jquery', 'layer', 'laydate', 'admin', 'config'], function () {
    var layer = layui.layer;
    var laydate = layui.laydate;
    var admin = layui.admin;
    var table = layui.table;
    var $ = layui.jquery;
    var config = layui.config;
    var curDate1 = getPreMonth(new Date(), 1);
    var addr = $.trim(window.location.protocol + "//" + window.location.host);
    var geoMapDataArr = [];

    var colorMap = {};

    /*窗口大小改变事件 图表自适应窗口大小*/
    window.onresize = function () {
        leftBar.resize();
        rightBar.resize();
        leftPie.resize();
        rightPie.resize();
        myChart.resize();
    };

    $.ajax({
        type: "post",
        url: addr + "/api/login/checkUserLogin",
        async: false,
        success: function (data) {
            if (data == true) {
                $.ajax({
                    type: 'post',
                    url: addr + '/api/login/findUserNameId',
                    async: false,
                    success: function (data) {
                        if (data.err == 'nologin') {
                            $('.header')
                                .vm({USERNAME: '暂无登录用户', isLogin: false});
                        } else {
                            data.isLogin = true;
                            $('.header')
                                .vm(data);
                        }
                    },
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        $('.header')
                            .vm({USERNAME: '暂无登录用户', isLogin: false});
                    }
                });
            } else {
                $('.header')
                    .vm({USERNAME: '暂无登录用户', isLogin: false});
            }
        },
        error: function (XMLHttpRequest, textStatus, errorThrown) {
            $('.header')
                .vm({USERNAME: '暂无登录用户'});
        }
    });

    /*初始化图表*/
    function initPageData() {
        setBarLeft("/api/map/latest/batch/declaration");
        setBarRight("/api/map/latest/batch/declaration?newEnergy=1");
        setPieLeft("/api/map/vehicle/distribution", '', 'init');
        setPieRight("/api/map/vehicle/distribution?newEnergy=1");
    }

    /*初始化柱状图图表*/
    var leftBar = echarts.init(document.getElementById("bar-left-chart"));
    var rightBar = echarts.init(document.getElementById("bar-right-chart"));
    var riskReasonPie = echarts.init(document.getElementById("riskReasonPie"));
    /*动态请求图表数据时间间隔标志*/
    var t1 = null;

    /**
     * 功能描述: 绘制左侧柱状图
     *
     * @param: 请求数据后台url
     * @return: null
     * @auther: quym
     * @date: 2018/11/11 22:27
     */
    function setBarLeft(url) {
        // clearTimeout(t1); //清除定时任务
        url = url + (url.indexOf('=') >= 0 ? '&' : '?') + "ym=" + getYm();
        admin.req(url, {}, function (res) {
            if (res.ok) {
                var json = res;
                if (res.data.length > 0) {
                    $(".bar-title")
                        .eq(0)
                        .text("第" + res.data[0].batch + "批公告新产品");
                }
                setValues_1(json, 'bar');
            } else {
                layer.msg(res.message);
            }
        });
    }

    function loadMapByType(areaName, type) {
        switch (type) {
            case 'init':
                clearTimeout(t1);
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                t1 = setTimeout(function () {

                    /*初始化地图*/
                    loadMap('100000', 'china', "");
                }, 250);
                break;
            case 'search':
                clearTimeout(t1);
                if ($(".search-input")
                    .val()) {
                    curDate1 = $("#search-input")
                        .val()
                        .replace("-", "");
                } else {
                    curDate1 = getPreMonth(new Date(), 1);
                }
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                t1 = setTimeout(function () {

                    /*初始化地图*/
                    loadMap('100000', 'china', "");
                }, 250);
                break;
            case 'mapselectchanged':
                clearTimeout(timeFn);
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                timeFn = setTimeout(function () {
                    var name = areaName;
                    var mapCode = cityMap[name];
                    if (!mapCode) {
                        layer.msg('无此区域地图显示');
                        return;
                    }
                    loadMap(mapCode, name);
                    //将上一级地图信息压入mapStack
                    mapStack.push({
                        mapCode: curMap.mapCode,
                        mapName: curMap.mapName
                    });

                    //判断省份div与城市div是否存在来动态改变地图标题
                    if ($(".province")
                        .is(":hidden") || $(".province")
                        .text() == "") {
                        $(".province")
                            .text('-' + name);
                        $(".province")
                            .show();
                    } else if ($(".province")
                        .is(":visible") && ($(".city")
                        .is(":hidden") || $(".city")
                        .text() == "")) {
                        $(".city")
                            .text('-' + name);
                        $(".province")
                            .show();
                        $(".city")
                            .show();
                    }
                    $("#area")
                        .val(name);
                }, 250);
                break;
            case 'contryclick-province':
                clearTimeout(timeFn);
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                timeFn = setTimeout(function () {
                    var map = mapStack.pop();
                    loadMap(map.mapCode, map.mapName, '');
                    $(".province")
                        .hide();
                }, 250);
                break;
            case 'contryclick-city':
                clearTimeout(timeFn);
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                timeFn = setTimeout(function () {
                    mapStack.pop();
                    var map1 = mapStack.pop();
                    loadMap(map1.mapCode, map1.mapName, '');
                    $(".province")
                        .hide();
                    $(".city")
                        .hide();
                }, 250);
                break;
            case 'provinceclick':
                clearTimeout(timeFn);
                //由于单击事件和双击事件冲突，故单击的响应事件延迟250毫秒执行
                timeFn = setTimeout(function () {
                    var map = mapStack.pop();
                    loadMap(map.mapCode, map.mapName);
                    $(".city")
                        .hide();
                }, 250);
                break;
        }
    }

    function setPieLeft(url, areaName, type) {
        // clearTimeout(t1); //清除定时任务
        url = url + (url.indexOf('=') >= 0 ? '&' : '?') + "ym=" + getYm();
        admin.req(url, {}, function (res) {
            if (res.ok) {
                var json = res;
                setValues_1(json, 'pie');
                loadMapByType(areaName, type);
            } else {
                layer.msg(res.message);
            }
        });
    }

    /*初始化饼图图表*/
    var leftPie = echarts.init(document.getElementById("pie-left-chart"));
    var rightPie = echarts.init(document.getElementById("pie-right-chart"));
    /*动态请求图表数据时间间隔标志*/
    var t2 = null;

    /**
     * 功能描述: 绘制左侧饼图
     *
     * @param: 请求数据后台url
     * @return: null
     * @auther: quym
     * @date: 2018/11/11 22:31
     */
    function setBarRight(url) {
        clearTimeout(t2); //清除定时任务
        url = url + (url.indexOf('=') >= 0 ? '&' : '?') + "ym=" + getYm();
        /*请求数据*/
        admin.req(url, {}, function (data) {
            var json = data;
            if (data.data.length > 0) {
                $(".bar-title")
                    .eq(1)
                    .text("第" + data.data[0].batch + "批新能源推荐目录新产品");
            }

            setValues_2(json, 'bar');
        });
    }

    function setPieRight(url) {
        clearTimeout(t2); //清除定时任务
        url = url + (url.indexOf('=') >= 0 ? '&' : '?') + "ym=" + getYm();
        /*请求数据*/
        admin.req(url, {}, function (data) {
            var json = data;
            setValues_2(json, 'pie');
        });
    }

    // 得到上个月
    function getPreMonth(date, type) {
        var year = date.getFullYear(); //获取当前日期的年份
        var month = date.getMonth() + 1; //获取当前日期的月份
        var days = new Date(year, month, 0);
        var dayNows = date.getDate(); //获取当前日期中月的天数
        //即每月13日运算后台算法程序，并更新显示上个月的数据，在此之前均应显示上上个月的数据；
        var dd = 1;
        if (dayNows < 13) {
            dd = 2;
        }
        var year2 = year;
        var month2 = month;
        if (month == 1) { //如果是1月份，则取上一年的12月份
            year2 = parseInt(year2) - 1;
            month2 = 12 + 1 - dd;
        } else {
            month2 = month2 - dd;
            if (month2 < 10) {
                month2 = '0' + month2;
            }
        }
        var t2 = type == 1 ? year2 + "" + month2 : year2 + "-" + month2;
        return t2;
    }

    /**
     * 功能描述: 供应商清单列表表格
     *
     * @param:
     * @return:
     * @auther: quym
     * @date: 2018/11/14 11:15
     */
    var renderTable = function (data, content, cols, elem) {
        if (!data) {
            data = [];
        }
        table.render({
            // table参数
            id: 'gys',
            elem: '#' + content,
            data: data,
            even: true,
            // height: 511,
            cols: cols,
            // page: {
            //     layout: ['limit', 'count', 'prev', 'page', 'next', 'skip']
            // },
            done: function () {

                adjustTbaleHeight(elem);

            }

        });
    };

    function renderTableByUrl(url, content, cols, elem) {
        var mainHeight = $('#' + elem)
            .height();
        var maxHeight = $('#' + elem)
            .parent()
            .height();
        var tableHeight = $('#' + elem + ' .layui-table-body')
            .height();
        table.render({
            // table参数
            id: 'gys',
            elem: '#' + content,
            url: url,
            even: true,
            cols: cols,
            page: true,
            height: 420,
            // response: {
            //     statusName: 'res.respCode', //数据状态的字段名称，默认：code
            //     statusCode: 0, //成功的状态码，默认：0
            //     msgName: 'res.message', //状态信息的字段名称，默认：msg
            //     countName: 'res.data.count', //数据总数的字段名称，默认：count
            //     dataName: 'res.data.list' //数据列表的字段名称，默认：data
            // },
            parseData: function (res) { //res 即为原始返回的数据
                return {
                    "code": parseInt(res.respCode), //解析接口状态
                    "msg": res.message, //解析提示文本
                    "count": res.data.count, //解析数据长度
                    "data": res.data.list //解析数据列表
                };
            },
            request: {
                pageName: 'offset', // 当前页数
                limitName: 'limit' // 每页容量
            }
        });
    }

    function adjustTbaleHeight(elem) {
        var mainHeight = $('#' + elem)
            .height();
        var maxHeight = $('#' + elem)
            .parent()
            .height();
        var tableHeight = $('#' + elem + ' .layui-table-body')
            .height();
        $('#' + elem + ' .layui-table-body')
            .css('height', (tableHeight + maxHeight - mainHeight - 20) + 'px')

    }

    var renderTable2 = function (data, cols) {


        if (!data) {
            data = [];
        }
        table.render({
            // table参数
            id: 'gys1',
            elem: '#tableContent1',
            data: data,
            even: true,
            cols: cols,

        });
    };

    /**
     * 功能描述: 风险主要产品表格
     *
     * @param:
     * @return:
     * @auther: quym
     * @date: 2018/11/14 11:15
     */
    var renderTable1 = function (params, type) {
        table.render({
            // table参数
            id: 'zycp',
            elem: '#tableContent2',
            url: admin.formatUrl(
                "/api/rms/risk-map/" + type + "-month/" + params.supplierCode + "/risk-part?riskYearMonth=" + params.riskYearMonth),
            initSort: {
                field: 'date', //排序字段，对应 cols 设定的各字段名
                type: 'desc' //排序方式  asc: 升序、desc: 降序、null: 默认排序
            },
            even: true,
            parseData: function (res) { //res 即为原始返回的数据
                return {
                    "code": res.respCode, //解析接口状态
                    "msg": res.message, //解析提示文本
                    // "count": total, //解析数据长度
                    "data": res.data //解析数据列表
                };
            },
            cols: [
                [{
                    type: 'numbers',
                    title: '序号'
                }, {
                    field: 'date',
                    title: '日期',
                    width: 110,
                    align: 'center'
                }, {
                    field: 'partsId',
                    title: '零件号',
                    width: 100,
                    align: 'center'
                }, {
                    field: 'partsName',
                    title: '零件名称',
                    width: 150,
                    align: 'center'
                }, {
                    field: 'type',
                    title: '质量事件',
                    align: 'center',
                    width: 120
                }, {
                    field: 'problemDsc',
                    title: '问题描述',
                    align: 'center',
                }]
            ],
            done: function () {


            }
        });
    };

    // 获得表格列
    function getCols(type, msg) {
        var col = [
            [
                {
                    type: 'numbers',
                    title: '序号',
                    width: '10%'
                },
                {
                    field: 'province',
                    title: '省份',
                    align: 'center',
                    width: '15%'
                },
                {
                    field: 'city',
                    title: '市',
                    align: 'center',
                    width: '25%'
                },
                {
                    field: 'companyName',
                    title: '企业名称',
                    align: 'center',
                    // width: '50%',
                    templet: function (d) {
                        return '<span title="' + d.companyName + '">' + d.companyName + '</span>';
                    }
                }
            ]
        ];
        return col;
        // var cols = [
        //     [{
        //         type: 'numbers',
        //         title: '序号',
        //         rowspan: 2
        //     }, {
        //         field: 'supplierCode',
        //         title: '供应商代码',
        //         align: 'center',
        //         rowspan: 2
        //     }, {
        //         field: 'supplierName',
        //         title: '供应商名称',
        //         align: 'center',
        //         rowspan: 2
        //     }, {
        //         field: 'functionName',
        //         title: '业务模块',
        //         width: 150,
        //         align: 'center',
        //         rowspan: 2
        //     }, {
        //         field: 'partsName',
        //         title: '主要供货产品',
        //         align: 'center',
        //         width: 120,
        //         rowspan: 2
        //     }, {
        //         field: 'message',
        //         title: msg,
        //         align: 'center',
        //         colspan: 4
        //     }, {
        //         title: '操作',
        //         align: 'center',
        //         rowspan: 2,
        //         templet: '#control'
        //     }],
        //     [{
        //         field: 'riskExpect',
        //         title: '风险暴露值',
        //         align: 'center',
        //         templet: function (d) {
        //             return d.riskExpect != null ? (d.riskExpect * 100).toFixed(2) + "%" : ""
        //         }
        //     }, {
        //         field: 'riskRank',
        //         title: '排名',
        //         align: 'center'
        //     }, {
        //         // field: 'change',
        //         title: '排名变化',
        //         align: 'center',
        //         templet: '#change'
        //     }, {
        //         field: 'riskLevel',
        //         title: '风险程度',
        //         align: 'center'
        //     }]
        // ];
        // var cols1 = [
        //     [{
        //         type: 'numbers',
        //         title: '序号',
        //         rowspan: 2
        //     }, {
        //         field: 'riskDate',
        //         title: '时间',
        //         align: 'center',
        //         minWidth: 80,
        //         rowspan: 2
        //     }, {
        //         field: 'supplierCode',
        //         title: '供应商代码',
        //         align: 'center',
        //         minWidth: 100,
        //         rowspan: 2
        //     }, {
        //         field: 'supplierName',
        //         title: '供应商名称',
        //         align: 'center',
        //         minWidth: 100,
        //         rowspan: 2
        //     }, {
        //         field: 'functionName',
        //         title: '业务模块',
        //         minWidth: 100,
        //         align: 'center',
        //         rowspan: 2
        //     }, {
        //         field: 'partsName',
        //         title: '主要供货产品',
        //         align: 'center',
        //         width: 120,
        //         rowspan: 2
        //     }, {
        //         field: 'message',
        //         title: msg,
        //         align: 'center',
        //         colspan: 4
        //     }, {
        //         title: '质量绩效表现',
        //         align: 'center',
        //         colspan: 7
        //     }],
        //     [{
        //         field: 'riskExpect',
        //         title: '风险暴露值',
        //         minWidth: 100,
        //         align: 'center',
        //         templet: function (d) {
        //             return d.riskExpect != null ? (d.riskExpect * 100).toFixed(2) + "%" : ""
        //         }
        //     }, {
        //         field: 'riskRank',
        //         title: '总体排名',
        //         minWidth: 100,
        //         align: 'center'
        //     }, {
        //         // field: 'change',
        //         title: '排名变化',
        //         align: 'center',
        //         minWidth: 100,
        //         templet: '#change'
        //     }, {
        //         field: 'riskLevel',
        //         title: '风险程度',
        //         minWidth: 100,
        //         align: 'center'
        //     }, {
        //         field: 'fieldProblemTimes',
        //         title: '现场问题数',
        //         minWidth: 120,
        //         align: 'center'
        //     }, {
        //         field: 'prrTimes',
        //         title: '质量PRR数',
        //         minWidth: 100,
        //         align: 'center'
        //     }, {
        //         field: 'prrProTimes',
        //         title: '程序PRR数',
        //         minWidth: 100,
        //         align: 'center'
        //     }, {
        //         field: 'dtTimes',
        //         title: 'DT',
        //         align: 'center'
        //     }, {
        //         field: 'csTimes',
        //         title: 'CS',
        //         align: 'center'
        //     }, {
        //         field: 'spillTimes',
        //         title: 'SPILL',
        //         minWidth: 80,
        //         align: 'center'
        //     }, {
        //         field: 'fpeTimes',
        //         title: 'FPE',
        //         align: 'center'
        //     }]
        // ];
        // if (type == 1) {
        //     return cols;
        // } else {
        //     return cols1;
        // }
    }

    // 表格操作列
    // table.on('tool(tableContent)', function (obj) {
    //     // 获取点击列的数据
    //     var data = obj.data;
    //     var layEvent = obj.event;
    //     // 判断操作类型
    //     if (layEvent === 'view') {
    //         layer.open({
    //             type: 1,
    //             content: $('#gysListView'),
    //             skin: 'whiteStyle',
    //             area: ['100%', '100%'],
    //             success: function (layero, index) {
    //                 //请求供应商清单信息,请求参数可从data中获取
    //                 admin.req("/api/rms/risk-map/three-month/" + data.supplierCode + "/detail?riskYearMonth=" + curDate1, {}, function (res) {
    //                     //渲染表格
    //                     renderTable2(res.data, getCols(0, "3个月滚动风险预警"));
    //                     var params = {};
    //                     params.supplierCode = data.supplierCode;
    //                     params.riskYearMonth = curDate1;
    //                     renderTable1(params, "three");
    //                 });
    //                 admin.req("/api/rms/risk-map/three-month/" + data.supplierCode + "/risk-reason?riskYearMonth=" + curDate1, {}, function (res) {
    //
    //                     setValues_3(res.data);
    //                     //setHighchart()
    //                 });
    //             }
    //         })
    //     }
    // });
    // 表格操作列
    // table.on('tool(tableContent3)', function (obj) {
    //     // 获取点击列的数据
    //     var data = obj.data;
    //     var layEvent = obj.event;
    //     // 判断操作类型
    //     if (layEvent === 'view') {
    //         layer.open({
    //             type: 1,
    //             content: $('#gysListView'),
    //             skin: 'whiteStyle',
    //             area: ['100%', '100%'],
    //             success: function (layero, index) {
    //                 //请求供应商清单信息,请求参数可从data中获取
    //                 admin.req("/api/rms/risk-map/twelve-month/" + data.supplierCode + "/detail?riskYearMonth=" + curDate1, {}, function (res) {
    //                     //渲染表格
    //                     renderTable2(res.data, getCols(0, "12个月滚动风险预警"));
    //                     var params = {};
    //                     params.supplierCode = data.supplierCode;
    //                     params.riskYearMonth = curDate1;
    //                     renderTable1(params, "twelve");
    //                 });
    //                 admin.req("/api/rms/risk-map/twelve-month/" + data.supplierCode + "/risk-reason?riskYearMonth=" + curDate1, {}, function (res) {
    //                     setValues_3(res.data);
    //                 });
    //             }
    //         })
    //     }
    // });

    /*初始化地图*/
    var myChart = echarts.init(document.getElementById('main'));
    //
    // /*左侧柱状图点击事件*/
    // leftBar.on('click', function (params) {
    //
    //     //弹出窗口
    //     layer.open({
    //         type: 1,
    //         title: '供应商清单信息',
    //         content: $("#gysListView"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
    //         area: ['100%', '100%'],
    //         skin: 'whiteStyle',
    //         // shade: 0.3,
    //         success: function (layero, index) {
    //             var supplierCode = params.name.split("-")[1];
    //             admin.req("/api/rms/risk-map/three-month/" + supplierCode + "/detail?riskYearMonth=" + curDate1, {}, function (res) {
    //                 //渲染表格
    //                 renderTable2(res.data, getCols(0, "3个月滚动风险预警"));
    //                 var params = {};
    //                 params.supplierCode = supplierCode;
    //                 params.riskYearMonth = curDate1;
    //                 renderTable1(params, "three");
    //             });
    //             admin.req("/api/rms/risk-map/three-month/" + supplierCode + "/risk-reason?riskYearMonth=" + curDate1, {}, function (res) {
    //                 setValues_3(res.data);
    //             });
    //         }
    //     });
    // });
    //
    // /*右侧柱状图点击事件*/
    // rightBar.on('click', function (params) {
    //     //弹出窗口
    //     layer.open({
    //         type: 1,
    //         title: '供应商清单信息',
    //         content: $("#gysListView"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
    //         area: ['100%', '100%'],
    //         skin: 'whiteStyle',
    //         // shade: 0.3,
    //         success: function (layero, index) {
    //             var supplierCode = params.name.split("-")[1];
    //             admin.req("/api/rms/risk-map/twelve-month/" + supplierCode + "/detail?riskYearMonth=" + curDate1, {}, function (res) {
    //                 //渲染表格
    //                 renderTable2(res.data, getCols(0, "12个月滚动风险预警"));
    //                 var params = {};
    //                 params.supplierCode = supplierCode;
    //                 params.riskYearMonth = curDate1;
    //                 renderTable1(params, "twelve");
    //             });
    //             admin.req("/api/rms/risk-map/twelve-month/" + supplierCode + "/risk-reason?riskYearMonth=" + curDate1, {}, function (res) {
    //                 setValues_3(res.data);
    //             });
    //         }
    //     });
    // });

    /*左侧饼图点击事件*/
    leftPie.on('click', function (params) {
        $.ajax({
            type: "post",
            url: addr + "/api/login/checkUserLogin",
            async: false,
            success: function (data) {
                if (data == true) {
                    if ($(".province")
                            .is(":visible")
                        && ['北京', '天津', '上海', '重庆'].indexOf($(".province")
                            .text()
                            .substring(1)) >= 0) {//弹出企业信息
                        // layer.open({
                        //     type: 1,
                        //     title: '企业明细',
                        //     skin: 'whiteStyle',
                        //     content: $("#gysList"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                        //     area: ['50%', '50%'],
                        //     // shade: 0.3,
                        //     success: function (layero, index) {
                        //         var date = curDate1;
                        //         var value = $("#area").val();
                        //         renderTableByUrl("/api/map/vehicle/detail?areaName=" + $(".province").text().substring(1), 'tableContent', getCols(1, "3个月滚动风险预警"), 'gysList');
                        //         //请求供应商清单信息, 请求参数可从params中取得，params.name和params.data
                        //         // admin.req("/api/map/vehicle/detail?areaName=" + $(".province").text().substring(1), {}, function (res) {
                        //         //     //渲染表格
                        //         //
                        //         // });
                        //     }
                        // });
                    } else if ($(".province")
                        .is(":visible") && $(".city")
                        .is(":visible") && $(".city")
                        .text() != "") {
                        //弹出企业信息
                        // layer.open({
                        //     type: 1,
                        //     title: '企业明细',
                        //     skin: 'whiteStyle',
                        //     content: $("#gysList"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                        //     area: ['50%', '50%'],
                        //     // shade: 0.3,
                        //     success: function (layero, index) {
                        //         var date = curDate1;
                        //         var value = $("#area").val();
                        //         renderTableByUrl("/api/map/vehicle/detail?areaName=" + $(".city").text().substring(1), 'tableContent', getCols(1, "3个月滚动风险预警"), 'gysList');
                        //         //请求供应商清单信息, 请求参数可从params中取得，params.name和params.data
                        //         // admin.req("/api/map/vehicle/detail?areaName=" + $(".city").text().substring(1), {}, function (res) {
                        //         //     //渲染表格
                        //         //
                        //         // });
                        //     }
                        // });
                    } else {
                        //弹出省市信息
                        layer.open({
                            type: 1,
                            title: '企业明细',
                            skin: 'whiteStyle',
                            content: $("#gysList"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                            area: ['50%', '50%'],
                            // shade: 0.3,
                            success: function (layero, index) {
                                var date = curDate1;
                                var value = $("#area")
                                    .val();
                                renderTableByUrl("/api/map/vehicle/detail?areaName=" + params.name,
                                    'tableContent', getCols(1, "3个月滚动风险预警"), 'gysList');
                                //请求供应商清单信息, 请求参数可从params中取得，params.name和params.data
                                // admin.req("/api/map/vehicle/detail?areaName=" + params.name, {}, function (res) {
                                //     //渲染表格
                                //
                                // });
                            }
                        });
                    }
                } else {
                    layer.msg('请登录后操作');
                }
            }
            ,
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                layer.msg('请登录后操作');
            }
        });

    });

    /*右侧饼图点击事件*/
    rightPie.on('click', function (params) {
        $.ajax({
            type: "post",
            url: addr + "/api/login/checkUserLogin",
            async: false,
            success: function (data) {
                if (data == true) {
                    if ($(".province")
                            .is(":visible")
                        && ['北京', '天津', '上海', '重庆'].indexOf($(".province")
                            .text()
                            .substring(1)) >= 0) {//弹出企业信息
                        // layer.open({
                        //     type: 1,
                        //     title: '企业明细',
                        //     skin: 'whiteStyle',
                        //     content: $("#gysList1"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                        //     area: ['50%', '50%'],
                        //     // shade: 0.3,
                        //     success: function (layero, index) {
                        //         var date = curDate1;
                        //         var value = $("#area").val();
                        //         renderTableByUrl("/api/map/vehicle/detail?newEnergy=1&areaName=" + $(".province").text().substring(1), 'tableContent3', getCols(1, "12个月滚动风险预警"), 'gysList1');
                        //         //请求供应商清单信息, 请求参数可从params中取得，params.name和params.data
                        //         // admin.req("/api/map/vehicle/detail?newEnergy=1&areaName=" + $(".province").text().substring(1), {}, function (res) {
                        //         //     //渲染表格
                        //         //
                        //         // });
                        //     }
                        // });
                    } else if ($(".province")
                        .is(":visible") && $(".city")
                        .is(":visible") && $(".city")
                        .text() != "") {
                        //弹出企业信息
                        // layer.open({
                        //     type: 1,
                        //     title: '企业明细',
                        //     skin: 'whiteStyle',
                        //     content: $("#gysList1"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                        //     area: ['50%', '50%'],
                        //     // shade: 0.3,
                        //     success: function (layero, index) {
                        //         var date = curDate1;
                        //         var value = $("#area").val();
                        //         renderTableByUrl("/api/map/vehicle/detail?newEnergy=1&areaName=" + $(".city").text().substring(1), 'tableContent3', getCols(1, "12个月滚动风险预警"), 'gysList1');
                        //         // //请求供应商清单信息,请求参数可从params中取得，params.name和params.data
                        //         // admin.req("/api/map/vehicle/detail?newEnergy=1&areaName=" + $(".city").text().substring(1), {}, function (res) {
                        //         //     //渲染表格
                        //         //
                        //         // });
                        //     }
                        // });
                    } else {
                        //弹出省市信息
                        layer.open({
                            type: 1,
                            title: '企业明细',
                            skin: 'whiteStyle',
                            content: $("#gysList1"), //这里content是一个URL，如果你不想让iframe出现滚动条，你还可以content: ['http://sentsin.com', 'no']
                            area: ['50%', '50%'],
                            // shade: 0.3,
                            success: function (layero, index) {
                                var date = curDate1;
                                var value = $("#area")
                                    .val();
                                renderTableByUrl(
                                    "/api/map/vehicle/detail?newEnergy=1&areaName=" + params.name,
                                    'tableContent3', getCols(1, "12个月滚动风险预警"), 'gysList1');
                                //请求供应商清单信息,请求参数可从params中取得，params.name和params.data
                                // admin.req("/api/map/vehicle/detail?newEnergy=1&areaName=" + params.name, {}, function (res) {
                                //     //渲染表格
                                //
                                // });
                            }
                        });
                    }
                } else {
                    layer.msg('请登录后操作');
                }
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                layer.msg('请登录后操作');
            }
        });
    });

    /*********************************** 绘制图表方法 *******************************************************************/
    // 柱状图颜色对应对象
    function colorObj(name) {
        // var colors = ["#ce3434", "#FDCD01", "#1C9FE7", "#25d982"];
        // return colors[Math.floor(Math.random() * 4)];
        var r = Math.floor(Math.random() * 256);
        var g = Math.floor(256 - Math.random() * 70);
        var b = Math.floor(256 - Math.random() * 70);
        return "rgb(" + r + ',' + g + ',' + b + ")";
    }

    /**
     * 功能描述: 组装echarts柱状图所需参数，并画出柱状图
     *
     * @param: 从后台请求的json数据
     * @return: null
     * @auther: quym
     * @date: 2018/11/11 22:38
     */
    function setValues_1(json, type) {
        /*柱状图参数数据*/
        var paramsLeftBar = {};
        var paramsLeftPie = {};
        switch (type) {
            case 'bar':
                var bar = json.data;
                // 判断左侧柱状图数据是否为空
                if (bar.length != 0) {
                    $("#bar-left-chart")
                        .removeClass("nodatastyle");
                    /*y轴数据*/
                    var namesBar = [];
                    /*x轴数据*/
                    var valuesBar = [];

                    var fullNamesBar = [];
                    /*循环json数据 赋值x轴、y轴数组数据*/
                    for (var item in bar) {
                        var supplierName = bar[item].shortName;
                        var fullName = bar[item].name;
                        var riskExpect = bar[item].amount;
                        valuesBar.push(riskExpect);
                        namesBar.push(supplierName);
                        fullNamesBar.push(fullName);
                    }
                    //组装参数
                    paramsLeftBar.dataY = namesBar;
                    paramsLeftBar.dataX = valuesBar;
                    paramsLeftBar.fullNames = fullNamesBar;
                    //清空图表区域
                    leftBar.clear();
                    //绘制柱状图
                    leftBar.setOption(getBarLeftOption(paramsLeftBar), true);
                } else {
                    leftBar.clear();
                    $("#bar-left-chart")
                        .addClass("nodatastyle");
                }
                break;
            case 'pie':
                var pie = json.data.pieVOList;
                var count = json.data.total;
                geoMapDataArr = pie;
                // 判断左侧饼状图数据是否为空
                if (pie.length != 0) {
                    $("#pie-left-chart")
                        .removeClass("nodatastyle");
                    var namesPie = [];
                    var fullNamesPie = [];
                    for (var item in pie) {
                        var name = pie[item].name;
                        var fullName = pie[item].fullName;
                        namesPie.push(name);
                        fullNamesPie.push(fullName);
                        pie[item].itemStyle = {};
                        pie[item].itemStyle.color = colorObj(pie[item].name);
                        pie[item].value = pie[item].amount;
                    }
                    paramsLeftPie.legend = namesPie;
                    paramsLeftPie.names = namesPie;
                    paramsLeftPie.fullNames = fullNamesPie;
                    paramsLeftPie.data = pie;
                    paramsLeftPie.totalCount = count;
                    leftPie.clear();
                    leftPie.setOption(getPieLeftOption(paramsLeftPie, 'left'), true);
                } else {
                    leftPie.clear();
                    $("#pie-left-chart")
                        .addClass("nodatastyle");
                }
                break;
        }
    }

    /**
     * 功能描述: 组装echarts饼图所需参数，并画出饼图
     *
     * @param: 从后台请求的json数据
     * @return: null
     * @auther: quym
     * @date: 2018/11/11 22:58
     */
    function setValues_2(json, type) {
        /*柱状图参数数据*/
        var paramsRightBar = {};
        var paramsRightPie = {};
        switch (type) {
            case 'bar':
                var bar = json.data;
                // 判断右侧柱状图数据是否为空
                if (bar.length != 0) {
                    $("#bar-right-chart")
                        .removeClass("nodatastyle");
                    /*y轴数据*/
                    var namesBar = [];
                    /*x轴数据*/
                    var valuesBar = [];
                    var fullNamesBar = [];
                    /*循环json数据 赋值x轴、y轴数组数据*/
                    for (var item in bar) {
                        var supplierName = bar[item].shortName;
                        var fullName = bar[item].name;
                        var riskExpect = bar[item].amount;
                        valuesBar.push(riskExpect);
                        namesBar.push(supplierName);
                        fullNamesBar.push(fullName);
                    }
                    //组装参数
                    paramsRightBar.dataY = namesBar;
                    paramsRightBar.dataX = valuesBar;
                    paramsRightBar.fullNames = fullNamesBar;
                    //清空图表区域
                    rightBar.clear();
                    //绘制柱状图
                    rightBar.setOption(getBarLeftOption(paramsRightBar), true);
                } else {
                    rightBar.clear();
                    $("#bar-right-chart")
                        .addClass("nodatastyle");
                }
                break;
            case 'pie':
                var pie = json.data.pieVOList;
                var count = json.data.total;
                // 判断右侧饼状图数据是否为空
                if (pie.length != 0) {
                    $("#pie-right-chart")
                        .removeClass("nodatastyle");
                    var namesPie = [];
                    var fullNamesPie = [];
                    for (var item in pie) {
                        var name = pie[item].name;
                        var fullName = pie[item].fullName;
                        namesPie.push(name);
                        fullNamesPie.push(fullName);
                        pie[item].itemStyle = {};
                        pie[item].itemStyle.color = colorObj(pie[item].name);
                        pie[item].value = pie[item].amount;
                    }
                    paramsRightPie.legend = namesPie;
                    paramsRightPie.names = namesPie;
                    paramsRightPie.fullNames = fullNamesPie;
                    paramsRightPie.data = pie;
                    paramsRightPie.totalCount = count;
                    rightPie.clear();
                    rightPie.setOption(getPieLeftOption(paramsRightPie, 'right'), true);
                } else {
                    rightPie.clear();
                    $("#pie-right-chart")
                        .addClass("nodatastyle");
                }
                break;
        }
    }

    // 风险原因饼状图  （2019-03-38修改为立体饼图 引入highCHart）
    function setValues_3(json) {
        //json.data=[{name:'111',count:1},{name:'111',count:2},{name:'111',count:3}]
        if (json.length > 0) {
            $("#async-img4")
                .hide();
            $("#riskReasonPie")
                .show();

        } else {
            $("#async-img4")
                .show();
            $("#riskReasonPie")
                .hide();
        }
        var pieData = [];
        for (var index in json) {
            var one = {
                name: json[index].name,
                y: json[index].count
            };
            pieData.push(one);

        }
        setHighchart('riskReasonPie', '风险主要原因类别', pieData);
        // /*柱状图参数数据*/
        // var paramsPie = {};
        // /*y轴数据*/
        // var namesPie = [];
        // /*x轴数据*/
        // var valuesPie = [];
        // /*循环json数据 赋值x轴、y轴数组数据*/
        // for (var item in json) {
        //     var obj = {};
        //     var value = json[item].count;
        //     var name = json[item].name;
        //     obj.name = name;
        //     obj.value = value;
        //     valuesPie.push(obj);
        //     namesPie.push(name);
        // }
        // //组装参数
        // paramsPie.legend = namesPie;
        // paramsPie.data = valuesPie;
        // //清空图表区域
        // riskReasonPie.clear();
        // //绘制柱状图
        // if (paramsPie.data.length != 0) {
        //     $("#async-img4").hide();
        //     $("#riskReasonPie").show();
        //     //$("#chart-pie-row div").append("<div id=\"chart-pie\" style=\"width: 96%;height: 260px;margin: 0 auto;\">");
        //     riskReasonPie.setOption(getRiskReasonPieOption(paramsPie), true);
        // } else {
        //     $("#async-img4").show();
        //
        //     $("#riskReasonPie").hide();
        // }
        // //riskReasonPie.setOption(getRiskReasonPieOption(paramsPie), true);
        // riskReasonPie.resize();


    }

    function setHighchart(elem, name, data) {
        var chart = Highcharts.chart(elem, {
            chart: {
                type: 'pie',
                options3d: {
                    enabled: true,
                    alpha: 45,
                    beta: 0
                }
            },
            exporting: {
                enabled: false
            },
            credits: {
                enabled: false
            },
            title: {
                text: name
            },
            tooltip: {
                pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
            },
            plotOptions: {
                pie: {
                    allowPointSelect: true,
                    cursor: 'pointer',
                    depth: 35,
                    dataLabels: {
                        enabled: true,
                        format: '{point.name}'
                    }
                }
            },
            series: [{
                type: 'pie',
                name: '风险主要原因',
                data: data
            }]
        });


    }

    /********************************************* 获得echarts图表所需option参数 *****************************************************/

    /**
     * 功能描述: 获取柱状图参数option
     *
     * @param: 组装的带有option所需数据的兑对象
     * @return: option
     * @auther: quym
     * @date: 2018/11/11 23:04
     */
    function getBarLeftOption(params) {
        var fullNames = params.fullNames;
        var shortNames = params.dataY;
        var option = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                },
                //自定义tooltip显示内容
                formatter: function (params) {
                    //显示内容
                    var result = params[0].name.split("-")[0];
                    result = fullNames[shortNames.indexOf(result)];
                    if (result.length > 12) {
                        result = result.substring(0, 12) + "<br>" + result.substring(12, result.length);
                    }
                    result += '，' + params[0].data;
                    //小圆点
                    // result += '<br>占比：' + (params[0].data * 100).toFixed(2) + '%';
                    return result;
                }
            },
            //柱状图柱条颜色
            color: ['#71B7EE'],
            //图表距容器距离
            grid: {
                top: '8%',
                left: '0%',
                right: '23.5%',
                bottom: '7%',
                containLabel: true
            },
            //x轴数据
            xAxis: {
                type: 'value',
                name: '  新产品数',
                // min: 0,
                // max: 100,36666
                boundaryGap: [0, 0.01],
                axisLine: {
                    lineStyle: {
                        color: '#71B7EE'
                    }
                },
                splitLine: {
                    lineStyle: {
                        type: 'dotted',
                        color: 'rgba(255,255,255,0.2)'
                    }
                },
                axisLabel: {
                    interval: 0,
                    color: '#FFFFFF',
                    formatter: function (value, index) {
                        return value;
                    },
                    showMinLabel: false
                }
            },
            //y轴数据
            yAxis: [{
                type: 'category',
                data: params.dataY,
                inverse: true,
                axisTick: {
                    show: false
                },
                axisLine: {
                    lineStyle: {
                        color: '#71B7EE'
                    }
                },
                axisLabel: {
                    color: '#FFFFFF',
                    interval: 0,
                    formatter: function (value, index) {
                        return value
                    }
                }
            }],
            //系列
            series: [{
                name: '2011年',
                type: 'bar',
                // barWidth: 10,
                barCategoryGap: '50%',
                stack: '总量',
                label: {
                    normal: {
                        show: false,
                        position: 'right',
                        color: '#FFFFFF'
                    }
                },
                data: params.dataX
            }],
            itemStyle: {
                color: '#71B7EE'
                /*new echarts.graphic.LinearGradient(
                                    0, 0, 1, 0,
                                    [
                                        {offset: 0, color: 'transparent'},
                                        {offset: 0.7, color: '#71B7EE'},
                                        {offset: 1, color: '#71B7EE'}
                                    ]
                                )*/
            }
        };
        return option;
    }

    /**
     * 功能描述: 获取饼状图参数option
     *
     * @param: 组装的带有option所需数据的对象
     * @return: option
     * @auther: quym
     * @date: 2018/11/11 23:10
     */
    function getPieLeftOption(params, type) {
        var total = 0;
        var names = params.names;
        var fullNames = params.fullNames;

        for (var index in params.data) {
            var item = params.data[index];
            total += (item.amount) - 0;
        }

        for (var index in params.data) {
            var item = params.data[index];
            item.percent = ((item.amount / total) * 100).toFixed(2) + '%';
            item.total = total;
        }

        var legendSelected = {};
        for (var i = 0; i < params.legend.length; i++) {
            var legend = params.legend[i];
            legendSelected[legend] = i < 10;
        }

        var option = {
            tooltip: {
                trigger: 'item',
                //自定义tooltip 无论 是否点击图例 显示的百分比都要一致
                formatter: function (params, ticket, callback) {
                    var content;
                    var name = fullNames[names.indexOf(params.name)];
                    if (name.length > 12) {
                        name = name.substring(0, 12) + "<br>" + name.substring(12, name.length);
                    }
                    if ($(".province")
                        .is(":visible") && $(".city")
                        .is(":visible") && $(".city")
                        .text() != "") {
                        content = params.marker + name + '，' + params.data.value;
                    } else {
                        if (type == 'left') {
                            content = params.marker + name + '，' + params.data.value;
                        } else if (type == 'right') {
                            content = params.marker + name + '，' + params.data.value;
                        }
                    }
                    return content;
                }
            },
            //饼图扇形颜色
            // color: ['#ce3434', '#FDCD01', '#1C9FE7', '#25d982'],
            //图例设置
            legend: {
                orient: 'vertical',
                type: 'scroll',
                // right: '10%',
                left: '70%',
                height: '68%',
                // bottom: '5%',
                top: 'middle',
                itemGap: 20,
                itemWidth: 8,
                itemHeight: 8,
                icon: 'circle',
                textStyle: {
                    color: '#FFFFFF'
                },
                pageIconColor: '#FFFFFF',
                pageIconInactiveColor: '#FFFFFF',
                pageTextStyle: {
                    color: '#FFFFFF'
                },
                selected: legendSelected,
                data: params.legend,
                //自定义图例内容
                formatter: function (name) {
                    var result = name;
                    for (var i = 0; i < params.data.length; i++) {
                        var item = params.data[i];
                        if (item.name == name) {
                            result = name + ' ' + item.value;
                            break;
                        }
                    }
                    return result;
                }
            },
            //系列
            series: [{
                name: '',
                type: 'pie',
                //圆环图
                radius: ['50%', '70%'],
                center: ['40%', '50%'],
                avoidLabelOverlap: false,
                label: {
                    normal: {
                        show: true,
                        position: 'center',
                        fontSize: 12,
                        color: '#4cd0ff',
                        formatter: function () {
                            return "企业总数:\n\n" + params.totalCount;
                        }
                    }
                },
                labelLine: {
                    normal: {
                        show: false
                    }
                },
                itemStyle: {
                    borderWidth: 2, //设置border的宽度有多大
                    borderColor: '#0f4175'
                },
                data: params.data
            }]
        };
        return option;
    }

    // 获取风险原因饼状图参数
    function getRiskReasonPieOption(params) {
        var option = {
            tooltip: {
                trigger: 'item'
            },
            color: ['#3ba0ff', '#36cbcb', '#4ecb74', '#fad337', '#ff867f', '#54e6e8', '#d554eb', '#56c0dd', '#fd9e5c', '#153fc4'],
            // legend: {
            //     orient: 'vertical',
            //     right: 10,
            //     top: 20,
            //     bottom: 20,
            //     data: data.legendData,

            //     selected: data.selected
            // },
            series: [{
                name: '风险主要原因',
                type: 'pie',
                radius: '40%',
                center: ['50%', '50%'],
                label: {
                    formatter: function (value) {
                        var newStr = "";
                        var start, end;
                        var name_len = value.name.length; //每个内容名称的长度
                        var max_name = 9; //每行最多显示的字数
                        var new_row = Math.ceil(name_len / max_name); // 最多能显示几行，向上取整比如2.1就是3行
                        if (name_len > max_name) { //如果长度大于每行最多显示的字数
                            for (var i = 0; i < new_row; i++) { //循环次数就是行数
                                var old = ''; //每次截取的字符
                                start = i * max_name; //截取的起点
                                end = start + max_name; //截取的终点
                                if (i == new_row - 1) { //最后一行就不换行了
                                    old = value.name.substring(start) + "\n" + value.value + "," + value.percent + "%";
                                } else {
                                    old = value.name.substring(start, end) + "\n";
                                }
                                newStr += old; //拼接字符串
                            }
                        } else { //如果小于每行最多显示的字数就返回原来的字符串
                            newStr = value.name + "\n" + value.value + "," + value.percent + "%";
                        }
                        return newStr;
                    }
                },
                data: params.data,
                itemStyle: {
                    emphasis: {
                        shadowBlur: 10,
                        shadowOffsetX: 0,
                        shadowColor: 'rgba(0, 0, 0, 0.5)'
                    }
                }
            }]
        };
        return option;
    }

    /*************************************** 页面上查询、导出按钮功能 ************************************************************/
    function setTitle() {
        $(".pie-title")
            .eq(0)
            .text("整车企业分布");
        $(".pie-title")
            .eq(1)
            .text("新能源企业分布");
    }

    setTitle();

    function getYm() {
        var curDate = new Date();
        //获得日期框数据
        var date = $(".search-input")
            .val() ? $(".search-input")
            .val() : getPreMonth(curDate);

        //分离日期数据为数组
        var dateArr = date.split("-");
        //获得年份
        var year = dateArr[0];
        //获得月份
        var month = dateArr[1];
        month = month.length === 1 ? ('0' + month) : month;

        return year + "" + month;
    }

    /*查询按钮点击功能*/
    $(".search-button")
        .click(function () {
            var curDate = new Date();
            //获得日期框数据
            var date = $(".search-input")
                .val() ? $(".search-input")
                .val() : getPreMonth(curDate);
            $("#area")
                .val("");
            $(".province")
                .hide();
            $(".city")
                .hide();

            //分离日期数据为数组
            var dateArr = date.split("-");
            //获得年份
            var year = dateArr[0];
            //获得月份
            var month = dateArr[1].indexOf("0") == 0 ? dateArr[1].substring(1) : dateArr[1];
            //动态改变图表标题文字，右侧标题比左侧标题月份+1
            // $(".bar-title").eq(0).text("第" + month + "批公告新产品");
            // $(".bar-title").eq(1).text("第" + month + "批新能源推荐目录新产品");
            // $(".pie-title").eq(0).text("整车企业分布");
            // $(".pie-title").eq(1).text("新能源企业分布");
            //绘制图表
            var value = $("#area")
                .val();
            // var url1 = $("#search-input").val() ? "/api/rms/risk-map/three-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + value : "/api/rms/risk-map/three-month/bar-pie?areaName=" + value;
            // var url2 = $("#search-input").val() ? "/api/rms/risk-map/twelve-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + value : "/api/rms/risk-map/twelve-month/bar-pie?areaName=" + value;
            // setBarLeft(url1);
            // setBarRight(url2);

            setBarLeft("/api/map/latest/batch/declaration?areaName=" + value);
            setBarRight("/api/map/latest/batch/declaration?newEnergy=1&areaName=" + value);
            setPieLeft("/api/map/vehicle/distribution?areaName=" + value, value, 'search');
            setPieRight("/api/map/vehicle/distribution?newEnergy=1&areaName=" + value);
        });

    /**************************************** 地图相关 ********************************************************/
        //存储切换的每一级地图信息
    var mapStack = [];
    var timeFn = null;
    var curMap = {};
    var flag = true;
    /**
     绑定用户切换地图区域事件
     cityMap对象存储着地图区域名称和区域的信息(name-code)
     当mapCode有值,说明可以切换到下级地图
     同时保存上级地图的编号和名称
     */
    myChart.on('mapselectchanged', function (params) {
        $.ajax({
            type: "post",
            url: addr + "/api/login/checkUserLogin",
            async: false,
            success: function (data) {
                if (data == true) {
                    var name = params.batch[0].name;
                    var mapCode = cityMap[name];
                    if (!mapCode) {
                        layer.msg('无此区域地图显示');
                        return;
                    }
                    //绘制图表，若需要传递省市参数，可在setBarLeft、setPieLeft方法中加一个data参数，具体参数值可从params中获取，发送请求时带上参数传到后台
                    // var url1 = $("#search-input").val() ? "/api/rms/risk-map/three-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + params.batch[0].name : "/api/rms/risk-map/three-month/bar-pie?areaName=" + params.batch[0].name;
                    // var url2 = $("#search-input").val() ? "/api/rms/risk-map/twelve-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + params.batch[0].name : "/api/rms/risk-map/twelve-month/bar-pie?areaName=" + params.batch[0].name;
                    // setBarLeft(url1);
                    // setBarRight(url2);
                    setBarLeft("/api/map/latest/batch/declaration?areaName=" + params.batch[0].name);
                    setBarRight(
                        "/api/map/latest/batch/declaration?newEnergy=1&areaName=" + params.batch[0].name);
                    setPieLeft("/api/map/vehicle/distribution?areaName=" + params.batch[0].name,
                        params.batch[0].name, 'mapselectchanged');
                    setPieRight("/api/map/vehicle/distribution?newEnergy=1&areaName=" + params.batch[0].name);
                } else {
                    layer.msg('请登录后操作');
                }
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                layer.msg('请登录后操作');
            }
        });
    });

    /**
     加载地图：根据地图所在省市的行政编号，
     获取对应的json地图数据，然后向echarts注册该区域的地图
     最后加载地图信息
     @params {String} mapCode:地图行政编号,for example['中国':'100000', '湖南': '430000']
     @params {String} mapName: 地图名称
     */
    function loadMap(mapCode, mapName, areaName) {
        //请求省市地图数据
        $.ajax({
            url: '../../lib/china-main-city/' + mapCode + '.json',
            dataType: "json",
            success: function (data) {
                var mapData = [];
                if (data) {
                    //注册地图
                    echarts.registerMap(mapName, data);
                    var arr = [];
                    for (var i = 0; i < geoMapDataArr.length; i++) {
                        var data = {};
                        var tmp = geoMapDataArr[i];
                        data.name = tmp.name;
                        data.value = tmp.amount;
                        data.itemStyle = {areaColor: colorObj(data.name)};
                        arr.push(data);
                    }
                    var option = {
                        // visualMap: {
                        //     min: 0,
                        //     max: 6000,
                        //     left: '15%',
                        //     top: '90%',
                        //     itemWidth: 10,
                        //     orient: 'horizontal',
                        //     inRange: {
                        //         color: ['#cff7fd', '#0061dc']
                        //     },
                        //     textStyle: {
                        //         color: "#FFFFFF"
                        //     },
                        //     calculable: true
                        // },
                        tooltip: {
                            show: true,
                            padding: 10,
                            enterable: true,
                            transitionDuration: 1,
                            textStyle: {
                                color: '#FFFFFF',
                                decoration: 'none'
                            },
                            formatter: function (params) {
                                if (params.data) {
                                    return params.data.name + "，" + params.data.value;
                                } else {
                                    return "无数据";
                                }
                            }
                        },
                        //主要为了地图整体外发光效果
                        geo: {
                            map: mapName,
                            show: true,
                            zoom: 1.1,
                            itemStyle: {
                                normal: {
                                    borderWidth: 5,
                                    borderColor: '#49c5fd',
                                    shadowColor: '#3588ff',
                                    shadowBlur: 30
                                }
                            }
                        },
                        series: [{
                            name: '',
                            type: 'map',
                            mapType: mapName,
                            selectedMode: 'single',
                            zoom: 1.1,
                            top: 'center',
                            itemStyle: {
                                normal: {
                                    borderColor: 'grey',
                                    areaColor: '#2678b2'
                                },
                                emphasis: {
                                    show: true,
                                    areaColor: '#275f9f',
                                    shadowBlur: 15,
                                    shadowColor: '#3588ff'
                                }
                            },
                            label: {
                                normal: {
                                    show: true,
                                    color: '#0d3f6e'
                                },
                                emphasis: {
                                    show: true,
                                    color: '#4f1725'
                                }
                            },
                            data: arr
                        }]
                    };
                    //绘制地图
                    myChart.setOption(option, true);
                    curMap = {
                        mapCode: mapCode,
                        mapName: mapName
                    };

                    $(".pie-title")
                        .eq(0)
                        .text((mapName == 'china' ? '全国' : mapName) + "整车企业分布");
                    $(".pie-title")
                        .eq(1)
                        .text((mapName == 'china' ? '全国' : mapName) + "新能源企业分布");
                } else {
                    layer.msg('无法加载该地图');
                }
            },
            error: function () {
                layer.msg('无法加载该地图');
            }
        });
    }

    /*********************************** 地图返回功能 **********************************************************/

    /*点击地图标题全国模块事件*/
    $(".contruy")
        .on("click", function () {
            if (mapStack.length == 0) {
                layer.msg('已经到达全国地图了');
                return;
            } else if (mapStack.length == 1) {
                setBarLeft("/api/map/latest/batch/declaration");
                setBarRight("/api/map/latest/batch/declaration?newEnergy=1");
                setPieLeft("/api/map/vehicle/distribution", '', 'contryclick-province');
                setPieRight("/api/map/vehicle/distribution?newEnergy=1");
            } else {
                setBarLeft("/api/map/latest/batch/declaration");
                setBarRight("/api/map/latest/batch/declaration?newEnergy=1");
                setPieLeft("/api/map/vehicle/distribution", '', 'contryclick-city');
                setPieRight("/api/map/vehicle/distribution?newEnergy=1");
            }
            $("#area")
                .val("");
            // var url1 = $("#search-input").val() ? "/api/rms/risk-map/three-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") : "/api/rms/risk-map/three-month/bar-pie";
            // var url2 = $("#search-input").val() ? "/api/rms/risk-map/twelve-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") : "/api/rms/risk-map/twelve-month/bar-pie";
            // setBarLeft(url1);
            // setBarRight(url2);
        });
    /*点击地图标题省份模块事件*/
    $(".province")
        .on("click", function () {
            if (mapStack.length == 1) {
                layer.msg('已经到达' + $(this)
                    .text()
                    .substring(1) + '地图了');
                return;
            } else if (mapStack.length == 2) {
                var value = $(this)
                    .text()
                    .substring(1);
                setBarLeft("/api/map/latest/batch/declaration?areaName=" + value);
                setBarRight("/api/map/latest/batch/declaration?newEnergy=1&areaName=" + value);
                setPieLeft("/api/map/vehicle/distribution?areaName=" + value, value, 'provinceclick');
                setPieRight("/api/map/vehicle/distribution?newEnergy=1&areaName=" + value);
                // var url1 = $("#search-input").val() ? "/api/rms/risk-map/three-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + value : "/api/rms/risk-map/three-month/bar-pie?areaName=" + value;
                // var url2 = $("#search-input").val() ? "/api/rms/risk-map/twelve-month/bar-pie?yearMonth=" + $("#search-input").val().replace("-", "") + "&areaName=" + value : "/api/rms/risk-map/twelve-month/bar-pie?areaName=" + value;
                // setBarLeft(url1);
                // setBarRight(url2);
                $("#area")
                    .val(value);
            }
        });
    /*点击地图标题城市模块事件*/
    $(".city")
        .on("click", function () {
            if (mapStack.length == 2) {
                layer.msg('已经到达' + $(this)
                    .text()
                    .substring(1) + '地图了');
                return;
            }
        })
    /***************************** 日期框 *****************************************/
    //日期框初始化
    laydate.render({
        elem: '#search-input', //或 elem: document.getElementById('test')、elem: lay('#test') 等
        type: 'month'
    });
    // 地图导航
    // $(".content-header-tab").on("click", "li", function (e) {
    //     switch (this.id) {
    //         case 'share_platform':
    //             window.location.href = "/adc/#adc/resourceSharing/share_platform.html";
    //             break;
    //         case 'meetDocument':
    //             window.location.href = "/adc/#adc/resourceSharing/meetDocument.html";
    //             break;
    //     }
    // });
    // 退出
    // $(".loginOut").on('click', function() {
    //     layer.confirm('确定退出登录？', function() {
    //         // admin.req('/api/logout', {}, function() {
    //         config.removeAccount();
    //         // replace() 方法不会在 History 对象中生成一个新的记录。当使用该方法时，新的 URL 将覆盖 History 对象中的当前记录。
    //         // location.replace('./login.html?redirect_to=' + window.location.hash);
    //         window.location.href = "/logout";
    //         // });
    //     });
    // })
    Math.formatFloat = function (f, digit) {
        var m = Math.pow(10, digit);
        return Math.round(f * m, 10) / m;
    }

    /*初始化图表*/
    initPageData();
});